# Adjustor
Home of the Adjustor tdp cli utility.
WIP.

## Development
Install to the same virtual environment as hhd to have Adjustor picked up
as a plugin upon restart, or to its own venv to use independently.
```python
pip install -e .
```